@@ -1,7 +1,6 @@
 from .interval import *
 from .dists import *
+# from .parametric import *
 from .pbox import *
-
-# from .copula import __all__
-from .core import *
-from .dependence import *
\ No newline at end of file
+from .copula import *
+from .core import *
\ No newline at end of file
