@@ -175,28 +175,48 @@ def __get_bounds(function_name = None,steps = 200,*args):
 
 
 def lognormal(mean, var, steps = 200):
-
-    x = np.linspace(0.001,0.999,steps)
+    '''
+    Creates a p-box for the lognormal distribution
+    
+    *Note: the parameters used are the mean and variance of the lognormal distribution not the mean and variance of the underlying normal*
+    See:
+    `[1]<https://en.wikipedia.org/wiki/Log-normal_distribution#Generation_and_parameters>`
+    `[2]<https://stackoverflow.com/questions/51906063/distribution-mean-and-standard-deviation-using-scipy-stats>`
+    
+    
+    Parameters
+    ----------
+    mean : 
+        mean of the lognormal distribution
+    var :
+        variance of the lognormal distribution
+    
+    Returns
+    ----------
+    Pbox
+        
+    '''
+    if steps > 1000:
+        x = np.linspace(1/steps,1-1/steps,steps)
+    else:
+        x = np.linspace(0.001,0.999,steps)
 
     if mean.__class__.__name__ != 'Interval':
         mean = Interval(mean,mean)
     if var.__class__.__name__ != 'Interval':
         var = Interval(var,var)
     
-    def finputs(mean,var):
-        # https://en.wikipedia.org/wiki/Log-normal_distribution#Generation_and_parameters
-        # https://stackoverflow.com/questions/51906063/distribution-mean-and-standard-deviation-using-scipy-stats
+    def __lognorm(mean, var):
     
-        return {
-            's':np.sqrt(var),
-            'loc':0,
-            'scale':np.log(mean)
-        }
+        sigma = np.sqrt(np.log1p(var/mean**2))
+        mu = np.log(mean) - 0.5*sigma*sigma
+    
+        return sps.lognorm(sigma, loc = 0,scale = np.exp(mu))
         
-    bound0 = sps.lognorm(**finputs(mean.left,var.left)).ppf(x)
-    bound1 = sps.lognorm(**finputs(mean.right,var.left)).ppf(x)
-    bound2 = sps.lognorm(**finputs(mean.left,var.right)).ppf(x)
-    bound3 = sps.lognorm(**finputs(mean.right,var.right)).ppf(x)
+    bound0 = __lognorm(mean.left,var.left).ppf(x)
+    bound1 = __lognorm(mean.right,var.left).ppf(x)
+    bound2 = __lognorm(mean.left,var.right).ppf(x)
+    bound3 = __lognorm(mean.right,var.right).ppf(x)
 
     Left = [min(bound0[i],bound1[i],bound2[i],bound3[i]) for i in range(steps)]
     Right = [max(bound0[i],bound1[i],bound2[i],bound3[i]) for i in range(steps)]
@@ -2667,8 +2687,8 @@ def min_max_mean_std(
     def _env(a,b) : 
         return Interval(min(_left(a),_left(b)),max(_right(a),_right(b)))    
     
-    def _constrain(a, b, msg) :
-        if ((right(a) < left(b)) or (right(b) < left(a))) : 
+    def _constrain(a, b, msg):
+        if ((_right(a) < _left(b)) or (_right(b) < _left(a))) : 
             print("Math Problem: impossible constraint", msg)
         return _imp(a,b)
     
@@ -2720,7 +2740,14 @@ def min_max_mean_std(
         R[i] = min(min(min(x2,x3),x6),one) * ran + minimum
   
     v = s**2
-    return Pbox(np.array(L),np.array(R),mean_left=left(m),mean_right=right(m),var_left=left(v),var_right=right(v),steps = steps)
+    return Pbox(
+        left = np.array(L),
+        right = np.array(R),
+        mean_left = _left(m),
+        mean_right = _right(m),
+        var_left = _left(v),
+        var_right = _right(v),
+        steps = steps)
 
 def min_max_mean_var(
         minimum: Union[Interval,float,int], 
@@ -2772,16 +2799,16 @@ def ME_min_max_mean_std(
         steps: int = Pbox.STEPS
         ) -> Pbox:
     
-    μ = ((mean- minimum) / (maximum - minimum))* (maximum - minimum) + minimum
+    μ = ((mean- minimum) / (maximum - minimum))
     
-    σ = (stddev/(maximum - minimum) )* (maximum - minimum) + minimum
+    σ = (stddev/(maximum - minimum) )
     
     a = ((1-μ)/(σ**2) - 1/μ)*μ**2
     b = a*(1/μ - 1)
     
-    return beta(a,b)
+    return beta(a,b,steps=steps)* (maximum - minimum) + minimum
 
-def beatpert(minimum, maximum, mode):
+def betapert(minimum, maximum, mode):
     mu = (minimum + maximum + 4*mode)/6
     alpha1 = (mu - minimum)*(2*mode - minimum - maximum)/((mode - mu)*(maximum - minimum))
     alpha2 = alpha1*(maximum - mu)/(mu - minimum)
