@@ -172,6 +172,16 @@ class Pbox:
     def __rmul__(self,other):
         return self.mul(other, method = 'f')
 
+    def __pow__(self,other):
+        return self.pow(other, method='f')
+    
+    def __rpow__(self,other):
+        if not hasattr(other, '__iter__'):
+            other = np.array((other))
+            
+        b = Pbox(other)
+        return b.pow(self, method='f')    
+    
     def __truediv__(self, other):
 
         return self.div(other, method = 'f')
@@ -182,13 +192,19 @@ class Pbox:
             return other * self.recip()
         except:
             return NotImplemented
-
-    def __pow__(self,other):
-        if isinstance(other,int):
-            return self.pow(other)
-        else: 
-            return NotImplemented
-        
+    
+    def leftmost(self): 
+        '''
+        Returns the left-most value in the interval
+        '''
+        return self.left[0]
+  
+    def rightmost(self): 
+        '''
+        Returns the right-most value in the interval
+        '''
+        return self.right[-1]  
+    
     ### Local functions ###
     def _computemoments(self):    # should we compute mean if it is a Cauchy, var if it's a t distribution?
         self.mean_left = np.max([self.mean_left, np.mean(self.left)])
@@ -331,6 +347,96 @@ class Pbox:
             except:
                 return NotImplemented
 
+    def pow(self, other: Union["Pbox",Interval,float,int], method  = 'f') -> "Pbox":
+        '''
+        Raises a p-box to the power of other using the defined dependency method
+        
+        :param other: Pbox, Interval or numeric type
+        :param method: 
+
+        :return: Pbox
+        :rtype: Pbox
+        
+        '''
+        if method not in ['f','p','o','i']:
+            raise ArithmeticError("Calculation method unkown")
+
+        if other.__class__.__name__ == 'Interval': 
+            other = Pbox(other, steps = self.steps)
+
+        if other.__class__.__name__ == 'Pbox':
+
+            if self.steps != other.steps:
+                raise ArithmeticError("Both Pboxes must have the same number of steps")
+
+            if method == 'f':
+
+                nleft  = np.empty(self.steps)
+                nright = np.empty(self.steps)
+
+                for i in range(0,self.steps):
+                    j = np.array(range(i, self.steps))
+                    k = np.array(range(self.steps - 1, i-1, -1))
+
+                    nright[i] = np.min(self.right[j] ** other.right[k])
+
+                    jj = np.array(range(0, i + 1))
+                    kk = np.array(range(i, -1 , -1))
+
+                    nleft[i] = np.max(self.left[jj] ** other.left[kk])
+
+            elif method == 'p':
+
+                nleft  = self.left ** other.left
+                nright = self.right ** other.right
+
+            elif method == 'o':
+
+                nleft  = self.left ** np.flip(other.right)
+                nright = self.right ** np.flip(other.left)
+
+            elif method == 'i':
+
+                nleft  = []
+                nright = []
+                for i in self.left:
+                    for j in other.left:
+                        nleft.append(i+j)
+                for ii in self.right:
+                    for jj in other.right:
+                        nright.append(ii+jj)
+
+            nleft.sort()
+            nright.sort()
+
+            return Pbox(
+                left    = nleft,
+                right   = nright,
+                steps   = self.steps
+            )
+
+        else:
+            try:
+                # Try adding constant
+                if self.shape in ['uniform','normal','cauchy','triangular','skew-normal']:
+                    s = self.shape
+                else:
+                    s = ''
+
+                return Pbox(
+                    left       = self.left ** other,
+                    right      = self.right ** other,
+                    shape      = s,
+                    mean_left  = self.mean_left ** other,
+                    mean_right = self.mean_right ** other,
+                    var_left   = self.var_left,
+                    var_right  = self.var_right,
+                    steps      = self.steps
+                )
+
+            except:
+                return NotImplemented
+
     def sub(self, other, method = 'f'):
 
         if method == 'o':
@@ -429,9 +535,6 @@ class Pbox:
             method = 'o'
 
         return self.mul(1/other, method)
-
-    def pow(self, n):
-        return self._unary(n, function = lambda x,n: x**n)
         
     def exp(self): 
         return self._unary(function = lambda x: x.exp())
@@ -600,7 +703,7 @@ class Pbox:
             except:
                 return NotImplemented
 
-    def trunc(self, a, b, method = 'f'):
+    def truncate(self, a, b, method = 'f'):
         '''
         Equivalent to self.min(a,method).max(b,method)
         '''
@@ -749,6 +852,12 @@ class Pbox:
         '''
         return Interval(self.mean_left,self.mean_right)
 
+    def median(self) -> Interval:
+        '''
+        Returns the median of the distribution
+        '''
+        return Interval(np.median(self.left),np.median(self.right))
+
     def support(self) -> Interval:
         return Interval(min(self.left),max(self.right))
 
@@ -842,7 +951,7 @@ def interp_step(u, steps=200):
     u = np.sort(u)
 
     seq = np.linspace(start=0, stop=len(u) - 0.00001, num=steps, endpoint=True)
-    seq = np.array([trunc(seq_val) for seq_val in seq])
+    seq = np.array([truncate(seq_val) for seq_val in seq])
     return u[seq]
 
 def interp_cubicspline(vals, steps=200):
@@ -991,7 +1100,7 @@ def _DivByZeroCheck(bound):
     return bound
         
 def truncate(pbox,min,max):
-    return pbox.trunc(min,max)
+    return pbox.truncate(min,max)
 
 def mixture(
     *args: Union[Pbox,Interval,float,int],
